@@ -30,6 +30,12 @@ def print_version(ctx, param, value):
     click.echo('Pequod CLI {}'.format(pequod_cli.__version__))
     ctx.exit()
 
+def configure_logging(loglevel):
+    # configure file logger to not clutter stdout with log lines
+    logging.basicConfig(level=loglevel, filename='/tmp/pequod-cli.log', format='%(asctime)s %(levelname)s %(name)s: %(message)s')
+    logging.getLogger('urllib3.connectionpool').setLevel(logging.WARNING)
+    logging.getLogger('requests.packages.urllib3.connectionpool').setLevel(logging.WARNING)
+
 @click.group(invoke_without_command=True, cls=AliasedGroup, context_settings=CONTEXT_SETTINGS)
 @click.option('--config-file', help='Use alternative config file', default=DEFAULT_CONFIG_FILE, metavar='PATH')
 @click.option('-c', '--cluster', envvar='PEQUOD_CLUSTER', help='Name of the cluster to use', default='default', metavar='NAME')
@@ -40,8 +46,7 @@ def cli(ctx, config_file, cluster, verbose):
     """
     Pequod cluster command line interface
     """
-    if verbose:
-        logging.basicConfig(level=logging.DEBUG)
+    configure_logging(logging.DEBUG if verbose else logging.INFO)
     fn = os.path.expanduser(config_file)
     data = {}
     if os.path.exists(fn):
@@ -308,12 +313,22 @@ def status(ctx):
     """
     for svc in ctx.all_core_services:
         action('Checking {}..'.format(svc.name))
+        has_errors = 0
+        total = 0
         try:
-            svc.get('/status')
+            for ep, success, msg in svc.status():
+                click.secho(' .', nl=False)
+                if not success:
+                    error(msg, nl=False)
+                    has_errors += 1
+                total += 1
         except Exception as e:
             error('ERROR: {}'.format(e))
         else:
-            ok()
+            if has_errors:
+                error('{}/{} FAILED'.format(has_errors, total))
+            else:
+                ok()
 
 
 def _tags(ctx, query=None):
@@ -324,11 +339,12 @@ def _tags(ctx, query=None):
             continue
         row['last_update_time'] = row['last_update'] / 1000
         row['command'] = ' '.join(row['container_setup']['command'])
+        row['has_manifest'] = bool(row['container_setup']['manifest_image_id'])
         rows.append(row)
 
     rows.sort(key=lambda x: x['last_update_time'])
 
-    COLS = 'repository_name application_name application_version command last_update_time'.split()
+    COLS = 'repository_name application_name application_version command has_manifest last_update_time'.split()
     print_table(COLS, rows)
 
 @registry.command()
@@ -396,6 +412,9 @@ def nodes(ctx):
         rows.sort(key=itemgetter('name'))
         print_table('name mac ipv4 ipv6 template_name template_version reboot maintenance'.split(), rows)
 
+def parse_version(v):
+    return tuple([int(x) for x in v.split(".")])
+
 @nodes.command()
 @click.argument('node_name')
 @click.argument('key_value', nargs=-1)
@@ -416,17 +435,17 @@ def update(ctx, node_name, key_value):
             raise click.UsageError('Invalid key: "{}" is not allowed'.format(key))
         if key == 'template_version' and val == 'latest':
             # special case: find out latest template and use it
-            latest_version = 0
+            latest_version = '0'
             for row in ctx.manager.get_templates():
                 if row['template_name'] == data['template_name']:
                     # TODO: only supports numeric versions right now :-P
                     try:
-                        if int(row['template_version']) > latest_version:
-                            latest_version = int(row['template_version'])
+                        if parse_version(row['template_version']) > parse_version(latest_version):
+                            latest_version = row['template_version']
                     except ValueError:
                         # ignore non-int versions
                         pass
-            val = str(latest_version)
+            val = latest_version
         data[key] = val
     action('Updating {}..'.format(node_name))
     ctx.manager.put('/nodes/{}'.format(node_name), data=data)
@@ -497,7 +516,7 @@ def upload_vault(ctx, vault_name, zone_name, directory):
 
     temp_tar_io = BytesIO()
     temp_tar = tarfile.open(fileobj=temp_tar_io, mode='w')
-    temp_tar.add(directory)
+    temp_tar.add(directory, arcname='/')
     temp_tar.close()
     raw_tar = temp_tar_io.getvalue()
     result = ctx.manager.put('/vaults/{}/{}/'.format(vault_name, zone_name),
