@@ -3,8 +3,8 @@ from pequod_cli.service import CoreService
 
 
 class ApplicationRegistry(CoreService):
-    def __init__(self, core_seeds, credentials):
-        super().__init__(core_seeds, 'application-registry', credentials)
+    def __init__(self, endpoints, credentials):
+        super().__init__(endpoints, 'application-registry', credentials)
 
     def get_manifest(self, repository_name, application_name, application_version):
         try:
